Class: Google::Apis::FileV1::CloudFilestoreService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::FileV1::CloudFilestoreService
- Defined in:
- lib/google/apis/file_v1/service.rb
Overview
Cloud Filestore API
The Cloud Filestore API is used for creating and managing cloud file servers.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://file.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_backup(parent, backup_object = nil, backup_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Creates a backup.
-
#create_project_location_instance(parent, instance_object = nil, instance_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Creates an instance.
-
#create_project_location_instance_snapshot(parent, snapshot_object = nil, snapshot_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Creates a snapshot.
-
#delete_project_location_backup(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Deletes a backup.
-
#delete_project_location_instance(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Deletes an instance.
-
#delete_project_location_instance_snapshot(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Deletes a snapshot.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Empty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Location
Gets information about a location.
-
#get_project_location_backup(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Backup
Gets the details of a specific backup.
-
#get_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Instance
Gets the details of a specific instance.
-
#get_project_location_instance_snapshot(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Snapshot
Gets the details of a specific snapshot.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ CloudFilestoreService
constructor
A new instance of CloudFilestoreService.
-
#list_project_location_backups(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::ListBackupsResponse
Lists all backups in a project for either a specified location or for all locations.
-
#list_project_location_instance_snapshots(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::ListSnapshotsResponse
Lists all snapshots in a project for either a specified location or for all locations.
-
#list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::ListInstancesResponse
Lists all instances in a project for either a specified location or for all locations.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_backup(name, backup_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Updates the settings of a specific backup.
-
#patch_project_location_instance(name, instance_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Updates the settings of a specific instance.
-
#patch_project_location_instance_snapshot(name, snapshot_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Updates the settings of a specific snapshot.
-
#pause_instance_replica(name, pause_replica_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Pause the standby instance (replica).
-
#promote_instance_replica(name, promote_replica_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Promote the standby instance (replica).
-
#restore_instance(name, restore_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Restores an existing instance's file share from a backup.
-
#resume_instance_replica(name, resume_replica_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Resume the standby instance (replica).
-
#revert_instance(name, revert_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Revert an existing instance's file system to a specified snapshot.
Constructor Details
#initialize ⇒ CloudFilestoreService
Returns a new instance of CloudFilestoreService.
47 48 49 50 51 52 |
# File 'lib/google/apis/file_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-file_v1', client_version: Google::Apis::FileV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/file_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/file_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
916 917 918 919 920 921 922 923 924 925 926 |
# File 'lib/google/apis/file_v1/service.rb', line 916 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::FileV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::FileV1::Empty::Representation command.response_class = Google::Apis::FileV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_backup(parent, backup_object = nil, backup_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Creates a backup.
169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/google/apis/file_v1/service.rb', line 169 def create_project_location_backup(parent, backup_object = nil, backup_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/backups', ) command.request_representation = Google::Apis::FileV1::Backup::Representation command.request_object = backup_object command.response_representation = Google::Apis::FileV1::Operation::Representation command.response_class = Google::Apis::FileV1::Operation command.params['parent'] = parent unless parent.nil? command.query['backupId'] = backup_id unless backup_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_instance(parent, instance_object = nil, instance_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Creates an instance. When creating from a backup, the capacity of the new instance needs to be equal to or larger than the capacity of the backup (and also equal to or larger than the minimum capacity of the tier).
358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/google/apis/file_v1/service.rb', line 358 def create_project_location_instance(parent, instance_object = nil, instance_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/instances', ) command.request_representation = Google::Apis::FileV1::Instance::Representation command.request_object = instance_object command.response_representation = Google::Apis::FileV1::Operation::Representation command.response_class = Google::Apis::FileV1::Operation command.params['parent'] = parent unless parent.nil? command.query['instanceId'] = instance_id unless instance_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_instance_snapshot(parent, snapshot_object = nil, snapshot_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Creates a snapshot.
725 726 727 728 729 730 731 732 733 734 735 736 |
# File 'lib/google/apis/file_v1/service.rb', line 725 def create_project_location_instance_snapshot(parent, snapshot_object = nil, snapshot_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/snapshots', ) command.request_representation = Google::Apis::FileV1::Snapshot::Representation command.request_object = snapshot_object command.response_representation = Google::Apis::FileV1::Operation::Representation command.response_class = Google::Apis::FileV1::Operation command.params['parent'] = parent unless parent.nil? command.query['snapshotId'] = snapshot_id unless snapshot_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_backup(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Deletes a backup.
203 204 205 206 207 208 209 210 211 |
# File 'lib/google/apis/file_v1/service.rb', line 203 def delete_project_location_backup(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::FileV1::Operation::Representation command.response_class = Google::Apis::FileV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_instance(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Deletes an instance.
395 396 397 398 399 400 401 402 403 404 |
# File 'lib/google/apis/file_v1/service.rb', line 395 def delete_project_location_instance(name, force: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::FileV1::Operation::Representation command.response_class = Google::Apis::FileV1::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_instance_snapshot(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Deletes a snapshot.
759 760 761 762 763 764 765 766 767 |
# File 'lib/google/apis/file_v1/service.rb', line 759 def delete_project_location_instance_snapshot(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::FileV1::Operation::Representation command.response_class = Google::Apis::FileV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
951 952 953 954 955 956 957 958 959 |
# File 'lib/google/apis/file_v1/service.rb', line 951 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::FileV1::Empty::Representation command.response_class = Google::Apis::FileV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/file_v1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::FileV1::Location::Representation command.response_class = Google::Apis::FileV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_backup(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Backup
Gets the details of a specific backup.
234 235 236 237 238 239 240 241 242 |
# File 'lib/google/apis/file_v1/service.rb', line 234 def get_project_location_backup(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::FileV1::Backup::Representation command.response_class = Google::Apis::FileV1::Backup command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Instance
Gets the details of a specific instance.
427 428 429 430 431 432 433 434 435 |
# File 'lib/google/apis/file_v1/service.rb', line 427 def get_project_location_instance(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::FileV1::Instance::Representation command.response_class = Google::Apis::FileV1::Instance command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance_snapshot(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Snapshot
Gets the details of a specific snapshot.
790 791 792 793 794 795 796 797 798 |
# File 'lib/google/apis/file_v1/service.rb', line 790 def get_project_location_instance_snapshot(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::FileV1::Snapshot::Representation command.response_class = Google::Apis::FileV1::Snapshot command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
982 983 984 985 986 987 988 989 990 |
# File 'lib/google/apis/file_v1/service.rb', line 982 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::FileV1::Operation::Representation command.response_class = Google::Apis::FileV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_backups(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::ListBackupsResponse
Lists all backups in a project for either a specified location or for all locations.
278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/google/apis/file_v1/service.rb', line 278 def list_project_location_backups(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/backups', ) command.response_representation = Google::Apis::FileV1::ListBackupsResponse::Representation command.response_class = Google::Apis::FileV1::ListBackupsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_instance_snapshots(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::ListSnapshotsResponse
Lists all snapshots in a project for either a specified location or for all locations.
834 835 836 837 838 839 840 841 842 843 844 845 846 847 |
# File 'lib/google/apis/file_v1/service.rb', line 834 def list_project_location_instance_snapshots(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/snapshots', ) command.response_representation = Google::Apis::FileV1::ListSnapshotsResponse::Representation command.response_class = Google::Apis::FileV1::ListSnapshotsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::ListInstancesResponse
Lists all instances in a project for either a specified location or for all locations.
470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'lib/google/apis/file_v1/service.rb', line 470 def list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/instances', ) command.response_representation = Google::Apis::FileV1::ListInstancesResponse::Representation command.response_class = Google::Apis::FileV1::ListInstancesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 |
# File 'lib/google/apis/file_v1/service.rb', line 1027 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::FileV1::ListOperationsResponse::Representation command.response_class = Google::Apis::FileV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/google/apis/file_v1/service.rb', line 126 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::FileV1::ListLocationsResponse::Representation command.response_class = Google::Apis::FileV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_backup(name, backup_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Updates the settings of a specific backup.
317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/google/apis/file_v1/service.rb', line 317 def patch_project_location_backup(name, backup_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::FileV1::Backup::Representation command.request_object = backup_object command.response_representation = Google::Apis::FileV1::Operation::Representation command.response_class = Google::Apis::FileV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_instance(name, instance_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Updates the settings of a specific instance.
511 512 513 514 515 516 517 518 519 520 521 522 |
# File 'lib/google/apis/file_v1/service.rb', line 511 def patch_project_location_instance(name, instance_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::FileV1::Instance::Representation command.request_object = instance_object command.response_representation = Google::Apis::FileV1::Operation::Representation command.response_class = Google::Apis::FileV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_instance_snapshot(name, snapshot_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Updates the settings of a specific snapshot.
875 876 877 878 879 880 881 882 883 884 885 886 |
# File 'lib/google/apis/file_v1/service.rb', line 875 def patch_project_location_instance_snapshot(name, snapshot_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::FileV1::Snapshot::Representation command.request_object = snapshot_object command.response_representation = Google::Apis::FileV1::Operation::Representation command.response_class = Google::Apis::FileV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#pause_instance_replica(name, pause_replica_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Pause the standby instance (replica). WARNING: This operation makes the standby instance's NFS filesystem writable. Any data written to the standby instance while paused will be lost when the replica is resumed or promoted.
548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/google/apis/file_v1/service.rb', line 548 def pause_instance_replica(name, pause_replica_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:pauseReplica', ) command.request_representation = Google::Apis::FileV1::PauseReplicaRequest::Representation command.request_object = pause_replica_request_object command.response_representation = Google::Apis::FileV1::Operation::Representation command.response_class = Google::Apis::FileV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#promote_instance_replica(name, promote_replica_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Promote the standby instance (replica).
582 583 584 585 586 587 588 589 590 591 592 |
# File 'lib/google/apis/file_v1/service.rb', line 582 def promote_instance_replica(name, promote_replica_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:promoteReplica', ) command.request_representation = Google::Apis::FileV1::PromoteReplicaRequest::Representation command.request_object = promote_replica_request_object command.response_representation = Google::Apis::FileV1::Operation::Representation command.response_class = Google::Apis::FileV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#restore_instance(name, restore_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Restores an existing instance's file share from a backup. The capacity of the instance needs to be equal to or larger than the capacity of the backup (and also equal to or larger than the minimum capacity of the tier).
618 619 620 621 622 623 624 625 626 627 628 |
# File 'lib/google/apis/file_v1/service.rb', line 618 def restore_instance(name, restore_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:restore', ) command.request_representation = Google::Apis::FileV1::RestoreInstanceRequest::Representation command.request_object = restore_instance_request_object command.response_representation = Google::Apis::FileV1::Operation::Representation command.response_class = Google::Apis::FileV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#resume_instance_replica(name, resume_replica_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Resume the standby instance (replica). WARNING: Any data written to the standby instance while paused will be lost when the replica is resumed.
653 654 655 656 657 658 659 660 661 662 663 |
# File 'lib/google/apis/file_v1/service.rb', line 653 def resume_instance_replica(name, resume_replica_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:resumeReplica', ) command.request_representation = Google::Apis::FileV1::ResumeReplicaRequest::Representation command.request_object = resume_replica_request_object command.response_representation = Google::Apis::FileV1::Operation::Representation command.response_class = Google::Apis::FileV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#revert_instance(name, revert_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1::Operation
Revert an existing instance's file system to a specified snapshot.
687 688 689 690 691 692 693 694 695 696 697 |
# File 'lib/google/apis/file_v1/service.rb', line 687 def revert_instance(name, revert_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:revert', ) command.request_representation = Google::Apis::FileV1::RevertInstanceRequest::Representation command.request_object = revert_instance_request_object command.response_representation = Google::Apis::FileV1::Operation::Representation command.response_class = Google::Apis::FileV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |