Class: Google::Apis::FileV1::DailyCycle
- Inherits:
-
Object
- Object
- Google::Apis::FileV1::DailyCycle
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1/classes.rb,
lib/google/apis/file_v1/representations.rb,
lib/google/apis/file_v1/representations.rb
Overview
Time window specified for daily operations.
Instance Attribute Summary collapse
-
#duration ⇒ String
Output only.
-
#start_time ⇒ Google::Apis::FileV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DailyCycle
constructor
A new instance of DailyCycle.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DailyCycle
Returns a new instance of DailyCycle.
181 182 183 |
# File 'lib/google/apis/file_v1/classes.rb', line 181 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ String
Output only. Duration of the time window, set by service producer.
Corresponds to the JSON property duration
172 173 174 |
# File 'lib/google/apis/file_v1/classes.rb', line 172 def duration @duration end |
#start_time ⇒ Google::Apis::FileV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
179 180 181 |
# File 'lib/google/apis/file_v1/classes.rb', line 179 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
186 187 188 189 |
# File 'lib/google/apis/file_v1/classes.rb', line 186 def update!(**args) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |