Class: Google::Apis::FileV1::DirectoryServicesConfig
- Inherits:
-
Object
- Object
- Google::Apis::FileV1::DirectoryServicesConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1/classes.rb,
lib/google/apis/file_v1/representations.rb,
lib/google/apis/file_v1/representations.rb
Overview
Directory Services configuration for Kerberos-based authentication.
Instance Attribute Summary collapse
-
#ldap ⇒ Google::Apis::FileV1::LdapConfig
LdapConfig contains all the parameters for connecting to LDAP servers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DirectoryServicesConfig
constructor
A new instance of DirectoryServicesConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DirectoryServicesConfig
Returns a new instance of DirectoryServicesConfig.
290 291 292 |
# File 'lib/google/apis/file_v1/classes.rb', line 290 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ldap ⇒ Google::Apis::FileV1::LdapConfig
LdapConfig contains all the parameters for connecting to LDAP servers.
Corresponds to the JSON property ldap
288 289 290 |
# File 'lib/google/apis/file_v1/classes.rb', line 288 def ldap @ldap end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
295 296 297 |
# File 'lib/google/apis/file_v1/classes.rb', line 295 def update!(**args) @ldap = args[:ldap] if args.key?(:ldap) end |