Class: Google::Apis::FileV1::GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSettings
- Inherits:
-
Object
- Object
- Google::Apis::FileV1::GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1/classes.rb,
lib/google/apis/file_v1/representations.rb,
lib/google/apis/file_v1/representations.rb
Overview
Maintenance settings associated with instance. Allows service producers and end users to assign settings that controls maintenance on this instance.
Instance Attribute Summary collapse
-
#exclude ⇒ Boolean
(also: #exclude?)
Optional.
-
#is_rollback ⇒ Boolean
(also: #is_rollback?)
Optional.
-
#maintenance_policies ⇒ Hash<String,Google::Apis::FileV1::MaintenancePolicy>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSettings
constructor
A new instance of GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSettings
Returns a new instance of GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSettings.
642 643 644 |
# File 'lib/google/apis/file_v1/classes.rb', line 642 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exclude ⇒ Boolean Also known as: exclude?
Optional. Exclude instance from maintenance. When true, rollout service will
not attempt maintenance on the instance. Rollout service will include the
instance in reported rollout progress as not attempted.
Corresponds to the JSON property exclude
623 624 625 |
# File 'lib/google/apis/file_v1/classes.rb', line 623 def exclude @exclude end |
#is_rollback ⇒ Boolean Also known as: is_rollback?
Optional. If the update call is triggered from rollback, set the value as true.
Corresponds to the JSON property isRollback
629 630 631 |
# File 'lib/google/apis/file_v1/classes.rb', line 629 def is_rollback @is_rollback end |
#maintenance_policies ⇒ Hash<String,Google::Apis::FileV1::MaintenancePolicy>
Optional. The MaintenancePolicies that have been attached to the instance. The
key must be of the type name of the oneof policy name defined in
MaintenancePolicy, and the embedded policy must define the same policy type.
For details, please refer to go/mr-user-guide. Should not be set if
maintenance_policy_names is set. If only the name is needed, then only
populate MaintenancePolicy.name.
Corresponds to the JSON property maintenancePolicies
640 641 642 |
# File 'lib/google/apis/file_v1/classes.rb', line 640 def maintenance_policies @maintenance_policies end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
647 648 649 650 651 |
# File 'lib/google/apis/file_v1/classes.rb', line 647 def update!(**args) @exclude = args[:exclude] if args.key?(:exclude) @is_rollback = args[:is_rollback] if args.key?(:is_rollback) @maintenance_policies = args[:maintenance_policies] if args.key?(:maintenance_policies) end |