Class: Google::Apis::FileV1::Instance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1/classes.rb,
lib/google/apis/file_v1/representations.rb,
lib/google/apis/file_v1/representations.rb

Overview

A Filestore instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



1010
1011
1012
# File 'lib/google/apis/file_v1/classes.rb', line 1010

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#capacity_step_size_gbFixnum

Output only. The incremental increase or decrease in capacity, designated in some number of GB. Corresponds to the JSON property capacityStepSizeGb

Returns:

  • (Fixnum)


858
859
860
# File 'lib/google/apis/file_v1/classes.rb', line 858

def capacity_step_size_gb
  @capacity_step_size_gb
end

#create_timeString

Output only. The time when the instance was created. Corresponds to the JSON property createTime

Returns:

  • (String)


863
864
865
# File 'lib/google/apis/file_v1/classes.rb', line 863

def create_time
  @create_time
end

#custom_performance_supportedBoolean Also known as: custom_performance_supported?

Output only. Indicates whether this instance supports configuring its performance. If true, the user can configure the instance's performance by using the 'performance_config' field. Corresponds to the JSON property customPerformanceSupported

Returns:

  • (Boolean)


870
871
872
# File 'lib/google/apis/file_v1/classes.rb', line 870

def custom_performance_supported
  @custom_performance_supported
end

#deletion_protection_enabledBoolean Also known as: deletion_protection_enabled?

Optional. Indicates whether the instance is protected against deletion. Corresponds to the JSON property deletionProtectionEnabled

Returns:

  • (Boolean)


876
877
878
# File 'lib/google/apis/file_v1/classes.rb', line 876

def deletion_protection_enabled
  @deletion_protection_enabled
end

#deletion_protection_reasonString

Optional. The reason for enabling deletion protection. Corresponds to the JSON property deletionProtectionReason

Returns:

  • (String)


882
883
884
# File 'lib/google/apis/file_v1/classes.rb', line 882

def deletion_protection_reason
  @deletion_protection_reason
end

#descriptionString

The description of the instance (2048 characters or less). Corresponds to the JSON property description

Returns:

  • (String)


887
888
889
# File 'lib/google/apis/file_v1/classes.rb', line 887

def description
  @description
end

#directory_servicesGoogle::Apis::FileV1::DirectoryServicesConfig

Directory Services configuration for Kerberos-based authentication. Corresponds to the JSON property directoryServices



892
893
894
# File 'lib/google/apis/file_v1/classes.rb', line 892

def directory_services
  @directory_services
end

#etagString

Server-specified ETag for the instance resource to prevent simultaneous updates from overwriting each other. Corresponds to the JSON property etag

Returns:

  • (String)


898
899
900
# File 'lib/google/apis/file_v1/classes.rb', line 898

def etag
  @etag
end

#file_sharesArray<Google::Apis::FileV1::FileShareConfig>

File system shares on the instance. For this version, only a single file share is supported. Corresponds to the JSON property fileShares



904
905
906
# File 'lib/google/apis/file_v1/classes.rb', line 904

def file_shares
  @file_shares
end

#kms_key_nameString

KMS key name used for data encryption. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


909
910
911
# File 'lib/google/apis/file_v1/classes.rb', line 909

def kms_key_name
  @kms_key_name
end

#labelsHash<String,String>

Resource labels to represent user provided metadata. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


914
915
916
# File 'lib/google/apis/file_v1/classes.rb', line 914

def labels
  @labels
end

#max_capacity_gbFixnum

Output only. The maximum capacity of the instance in GB. Corresponds to the JSON property maxCapacityGb

Returns:

  • (Fixnum)


919
920
921
# File 'lib/google/apis/file_v1/classes.rb', line 919

def max_capacity_gb
  @max_capacity_gb
end

#min_capacity_gbFixnum

Output only. The minimum capacity of the instance in GB. Corresponds to the JSON property minCapacityGb

Returns:

  • (Fixnum)


924
925
926
# File 'lib/google/apis/file_v1/classes.rb', line 924

def min_capacity_gb
  @min_capacity_gb
end

#nameString

Output only. The resource name of the instance, in the format projects/ project/locations/location/instances/instance`. Corresponds to the JSON propertyname`

Returns:

  • (String)


930
931
932
# File 'lib/google/apis/file_v1/classes.rb', line 930

def name
  @name
end

#networksArray<Google::Apis::FileV1::NetworkConfig>

VPC networks to which the instance is connected. For this version, only a single network is supported. Corresponds to the JSON property networks



936
937
938
# File 'lib/google/apis/file_v1/classes.rb', line 936

def networks
  @networks
end

#performance_configGoogle::Apis::FileV1::PerformanceConfig

Used for setting the performance configuration. If the user doesn't specify PerformanceConfig, automatically provision the default performance settings as described in https://cloud.google.com/filestore/docs/performance. Larger instances will be linearly set to more IOPS. If the instance's capacity is increased or decreased, its performance will be automatically adjusted upwards or downwards accordingly (respectively). Corresponds to the JSON property performanceConfig



946
947
948
# File 'lib/google/apis/file_v1/classes.rb', line 946

def performance_config
  @performance_config
end

#performance_limitsGoogle::Apis::FileV1::PerformanceLimits

The enforced performance limits, calculated from the instance's performance configuration. Corresponds to the JSON property performanceLimits



952
953
954
# File 'lib/google/apis/file_v1/classes.rb', line 952

def performance_limits
  @performance_limits
end

#protocolString

Immutable. The protocol indicates the access protocol for all shares in the instance. This field is immutable and it cannot be changed after the instance has been created. Default value: NFS_V3. Corresponds to the JSON property protocol

Returns:

  • (String)


959
960
961
# File 'lib/google/apis/file_v1/classes.rb', line 959

def protocol
  @protocol
end

#replicationGoogle::Apis::FileV1::Replication

Optional. The configuration used to replicate an instance. Corresponds to the JSON property replication



964
965
966
# File 'lib/google/apis/file_v1/classes.rb', line 964

def replication
  @replication
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


969
970
971
# File 'lib/google/apis/file_v1/classes.rb', line 969

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


975
976
977
# File 'lib/google/apis/file_v1/classes.rb', line 975

def satisfies_pzs
  @satisfies_pzs
end

#stateString

Output only. The instance state. Corresponds to the JSON property state

Returns:

  • (String)


981
982
983
# File 'lib/google/apis/file_v1/classes.rb', line 981

def state
  @state
end

#status_messageString

Output only. Additional information about the instance state, if available. Corresponds to the JSON property statusMessage

Returns:

  • (String)


986
987
988
# File 'lib/google/apis/file_v1/classes.rb', line 986

def status_message
  @status_message
end

#suspension_reasonsArray<String>

Output only. Field indicates all the reasons the instance is in "SUSPENDED" state. Corresponds to the JSON property suspensionReasons

Returns:

  • (Array<String>)


992
993
994
# File 'lib/google/apis/file_v1/classes.rb', line 992

def suspension_reasons
  @suspension_reasons
end

#tagsHash<String,String>

Optional. Input only. Immutable. Tag key-value pairs bound to this resource. Each key must be a namespaced name and each value a short name. Example: " 123456789012/environment" : "production", "123456789013/costCenter" : " marketing" See the documentation for more information: - Namespaced name: https://cloud.google.com/resource-manager/docs/tags/tags-creating-and-managing# retrieving_tag_key - Short name: https://cloud.google.com/resource-manager/ docs/tags/tags-creating-and-managing#retrieving_tag_value Corresponds to the JSON property tags

Returns:

  • (Hash<String,String>)


1003
1004
1005
# File 'lib/google/apis/file_v1/classes.rb', line 1003

def tags
  @tags
end

#tierString

The service tier of the instance. Corresponds to the JSON property tier

Returns:

  • (String)


1008
1009
1010
# File 'lib/google/apis/file_v1/classes.rb', line 1008

def tier
  @tier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
# File 'lib/google/apis/file_v1/classes.rb', line 1015

def update!(**args)
  @capacity_step_size_gb = args[:capacity_step_size_gb] if args.key?(:capacity_step_size_gb)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_performance_supported = args[:custom_performance_supported] if args.key?(:custom_performance_supported)
  @deletion_protection_enabled = args[:deletion_protection_enabled] if args.key?(:deletion_protection_enabled)
  @deletion_protection_reason = args[:deletion_protection_reason] if args.key?(:deletion_protection_reason)
  @description = args[:description] if args.key?(:description)
  @directory_services = args[:directory_services] if args.key?(:directory_services)
  @etag = args[:etag] if args.key?(:etag)
  @file_shares = args[:file_shares] if args.key?(:file_shares)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @labels = args[:labels] if args.key?(:labels)
  @max_capacity_gb = args[:max_capacity_gb] if args.key?(:max_capacity_gb)
  @min_capacity_gb = args[:min_capacity_gb] if args.key?(:min_capacity_gb)
  @name = args[:name] if args.key?(:name)
  @networks = args[:networks] if args.key?(:networks)
  @performance_config = args[:performance_config] if args.key?(:performance_config)
  @performance_limits = args[:performance_limits] if args.key?(:performance_limits)
  @protocol = args[:protocol] if args.key?(:protocol)
  @replication = args[:replication] if args.key?(:replication)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @state = args[:state] if args.key?(:state)
  @status_message = args[:status_message] if args.key?(:status_message)
  @suspension_reasons = args[:suspension_reasons] if args.key?(:suspension_reasons)
  @tags = args[:tags] if args.key?(:tags)
  @tier = args[:tier] if args.key?(:tier)
end