Class: Google::Apis::FileV1::ListBackupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1/classes.rb,
lib/google/apis/file_v1/representations.rb,
lib/google/apis/file_v1/representations.rb

Overview

ListBackupsResponse is the result of ListBackupsRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupsResponse

Returns a new instance of ListBackupsResponse.



1114
1115
1116
# File 'lib/google/apis/file_v1/classes.rb', line 1114

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupsArray<Google::Apis::FileV1::Backup>

A list of backups in the project for the specified location. If the `location value in the request is "-", the response contains a list of backups from all locations. If any location is unreachable, the response will only return backups in reachable locations and the "unreachable" field will be populated with a list of unreachable locations. Corresponds to the JSON propertybackups`

Returns:



1101
1102
1103
# File 'lib/google/apis/file_v1/classes.rb', line 1101

def backups
  @backups
end

#next_page_tokenString

The token you can use to retrieve the next page of results. Not returned if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1107
1108
1109
# File 'lib/google/apis/file_v1/classes.rb', line 1107

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unordered list. Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1112
1113
1114
# File 'lib/google/apis/file_v1/classes.rb', line 1112

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1119
1120
1121
1122
1123
# File 'lib/google/apis/file_v1/classes.rb', line 1119

def update!(**args)
  @backups = args[:backups] if args.key?(:backups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end