Class: Google::Apis::FileV1::ListSnapshotsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1/classes.rb,
lib/google/apis/file_v1/representations.rb,
lib/google/apis/file_v1/representations.rb

Overview

ListSnapshotsResponse is the result of ListSnapshotsRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSnapshotsResponse

Returns a new instance of ListSnapshotsResponse.



1241
1242
1243
# File 'lib/google/apis/file_v1/classes.rb', line 1241

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The token you can use to retrieve the next page of results. Not returned if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1229
1230
1231
# File 'lib/google/apis/file_v1/classes.rb', line 1229

def next_page_token
  @next_page_token
end

#snapshotsArray<Google::Apis::FileV1::Snapshot>

A list of snapshots in the project for the specified instance. Corresponds to the JSON property snapshots

Returns:



1234
1235
1236
# File 'lib/google/apis/file_v1/classes.rb', line 1234

def snapshots
  @snapshots
end

#unreachableArray<String>

Unordered list. Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1239
1240
1241
# File 'lib/google/apis/file_v1/classes.rb', line 1239

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1246
1247
1248
1249
1250
# File 'lib/google/apis/file_v1/classes.rb', line 1246

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @snapshots = args[:snapshots] if args.key?(:snapshots)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end