Class: Google::Apis::FileV1::NetworkConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1/classes.rb,
lib/google/apis/file_v1/representations.rb,
lib/google/apis/file_v1/representations.rb

Overview

Network configuration for the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkConfig

Returns a new instance of NetworkConfig.



1438
1439
1440
# File 'lib/google/apis/file_v1/classes.rb', line 1438

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connect_modeString

The network connect mode of the Filestore instance. If not provided, the connect mode defaults to DIRECT_PEERING. Corresponds to the JSON property connectMode

Returns:

  • (String)


1395
1396
1397
# File 'lib/google/apis/file_v1/classes.rb', line 1395

def connect_mode
  @connect_mode
end

#ip_addressesArray<String>

Output only. IPv4 addresses in the format octet1`.`octet2`.`octet3`.`octet4 or IPv6 addresses in the format block1`:`block2`:`block3`:`block4`:`block5`: `block6`:`block7`:`block8. Corresponds to the JSON property ipAddresses

Returns:

  • (Array<String>)


1402
1403
1404
# File 'lib/google/apis/file_v1/classes.rb', line 1402

def ip_addresses
  @ip_addresses
end

#modesArray<String>

Internet protocol versions for which the instance has IP addresses assigned. Corresponds to the JSON property modes

Returns:

  • (Array<String>)


1407
1408
1409
# File 'lib/google/apis/file_v1/classes.rb', line 1407

def modes
  @modes
end

#networkString

The name of the Google Compute Engine VPC network to which the instance is connected. Corresponds to the JSON property network

Returns:

  • (String)


1413
1414
1415
# File 'lib/google/apis/file_v1/classes.rb', line 1413

def network
  @network
end

#psc_configGoogle::Apis::FileV1::PscConfig

Private Service Connect configuration. Corresponds to the JSON property pscConfig



1418
1419
1420
# File 'lib/google/apis/file_v1/classes.rb', line 1418

def psc_config
  @psc_config
end

#reserved_ip_rangeString

Optional, reserved_ip_range can have one of the following two types of values.

  • CIDR range value when using DIRECT_PEERING connect mode. * Allocated IP address range when using PRIVATE_SERVICE_ACCESS connect mode. When the name of an allocated IP address range is specified, it must be one of the ranges associated with the private service access connection. When specified as a direct CIDR value, it must be a /29 CIDR block for Basic tier, a /24 CIDR block for High Scale tier, or a /26 CIDR block for Enterprise tier in one of the internal IP address ranges that identifies the range of IP addresses reserved for this instance. For example, 10.0.0.0/29, 192.168.0.0/24 or 192.168.0.0/26, respectively. The range you specify can't overlap with either existing subnets or assigned IP address ranges for other Filestore instances in the selected VPC network. Corresponds to the JSON property reservedIpRange

Returns:

  • (String)


1436
1437
1438
# File 'lib/google/apis/file_v1/classes.rb', line 1436

def reserved_ip_range
  @reserved_ip_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/google/apis/file_v1/classes.rb', line 1443

def update!(**args)
  @connect_mode = args[:connect_mode] if args.key?(:connect_mode)
  @ip_addresses = args[:ip_addresses] if args.key?(:ip_addresses)
  @modes = args[:modes] if args.key?(:modes)
  @network = args[:network] if args.key?(:network)
  @psc_config = args[:psc_config] if args.key?(:psc_config)
  @reserved_ip_range = args[:reserved_ip_range] if args.key?(:reserved_ip_range)
end