Class: Google::Apis::FileV1::NfsExportOptions
- Inherits:
-
Object
- Object
- Google::Apis::FileV1::NfsExportOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1/classes.rb,
lib/google/apis/file_v1/representations.rb,
lib/google/apis/file_v1/representations.rb
Overview
NFS export options specifications.
Instance Attribute Summary collapse
-
#access_mode ⇒ String
Either READ_ONLY, for allowing only read requests on the exported directory, or READ_WRITE, for allowing both read and write requests.
-
#anon_gid ⇒ Fixnum
An integer representing the anonymous group id with a default value of 65534.
-
#anon_uid ⇒ Fixnum
An integer representing the anonymous user id with a default value of 65534.
-
#ip_ranges ⇒ Array<String>
List of either an IPv4 addresses in the format
octet1`.`octet2`.`octet3`.` octet4or CIDR ranges in the formatoctet1`.`octet2`.`octet3`.`octet4`/` mask sizewhich may mount the file share. -
#network ⇒ String
Optional.
-
#squash_mode ⇒ String
Either NO_ROOT_SQUASH, for allowing root access on the exported directory, or ROOT_SQUASH, for not allowing root access.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NfsExportOptions
constructor
A new instance of NfsExportOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NfsExportOptions
Returns a new instance of NfsExportOptions.
1503 1504 1505 |
# File 'lib/google/apis/file_v1/classes.rb', line 1503 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_mode ⇒ String
Either READ_ONLY, for allowing only read requests on the exported directory,
or READ_WRITE, for allowing both read and write requests. The default is
READ_WRITE.
Corresponds to the JSON property accessMode
1464 1465 1466 |
# File 'lib/google/apis/file_v1/classes.rb', line 1464 def access_mode @access_mode end |
#anon_gid ⇒ Fixnum
An integer representing the anonymous group id with a default value of 65534.
Anon_gid may only be set with squash_mode of ROOT_SQUASH. An error will be
returned if this field is specified for other squash_mode settings.
Corresponds to the JSON property anonGid
1471 1472 1473 |
# File 'lib/google/apis/file_v1/classes.rb', line 1471 def anon_gid @anon_gid end |
#anon_uid ⇒ Fixnum
An integer representing the anonymous user id with a default value of 65534.
Anon_uid may only be set with squash_mode of ROOT_SQUASH. An error will be
returned if this field is specified for other squash_mode settings.
Corresponds to the JSON property anonUid
1478 1479 1480 |
# File 'lib/google/apis/file_v1/classes.rb', line 1478 def anon_uid @anon_uid end |
#ip_ranges ⇒ Array<String>
List of either an IPv4 addresses in the format octet1`.`octet2`.`octet3`.`
octet4 or CIDR ranges in the format octet1`.`octet2`.`octet3`.`octet4`/`
mask size which may mount the file share. Overlapping IP ranges are not
allowed, both within and across NfsExportOptions. An error will be returned.
The limit is 64 IP ranges/addresses for each FileShareConfig among all
NfsExportOptions.
Corresponds to the JSON property ipRanges
1488 1489 1490 |
# File 'lib/google/apis/file_v1/classes.rb', line 1488 def ip_ranges @ip_ranges end |
#network ⇒ String
Optional. The source VPC network for ip_ranges. Required for instances using
Private Service Connect, optional otherwise. If provided, must be the same
network specified in the NetworkConfig.network field.
Corresponds to the JSON property network
1495 1496 1497 |
# File 'lib/google/apis/file_v1/classes.rb', line 1495 def network @network end |
#squash_mode ⇒ String
Either NO_ROOT_SQUASH, for allowing root access on the exported directory, or
ROOT_SQUASH, for not allowing root access. The default is NO_ROOT_SQUASH.
Corresponds to the JSON property squashMode
1501 1502 1503 |
# File 'lib/google/apis/file_v1/classes.rb', line 1501 def squash_mode @squash_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1508 1509 1510 1511 1512 1513 1514 1515 |
# File 'lib/google/apis/file_v1/classes.rb', line 1508 def update!(**args) @access_mode = args[:access_mode] if args.key?(:access_mode) @anon_gid = args[:anon_gid] if args.key?(:anon_gid) @anon_uid = args[:anon_uid] if args.key?(:anon_uid) @ip_ranges = args[:ip_ranges] if args.key?(:ip_ranges) @network = args[:network] if args.key?(:network) @squash_mode = args[:squash_mode] if args.key?(:squash_mode) end |