Class: Google::Apis::FileV1::Replication

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1/classes.rb,
lib/google/apis/file_v1/representations.rb,
lib/google/apis/file_v1/representations.rb

Overview

Optional. The configuration used to replicate an instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Replication

Returns a new instance of Replication.



1829
1830
1831
# File 'lib/google/apis/file_v1/classes.rb', line 1829

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#replicasArray<Google::Apis::FileV1::ReplicaConfig>

Optional. Replication configuration for the replica instance associated with this instance. Only a single replica is supported. Corresponds to the JSON property replicas



1821
1822
1823
# File 'lib/google/apis/file_v1/classes.rb', line 1821

def replicas
  @replicas
end

#roleString

Optional. The replication role. When creating a new replica, this field must be set to STANDBY. Corresponds to the JSON property role

Returns:

  • (String)


1827
1828
1829
# File 'lib/google/apis/file_v1/classes.rb', line 1827

def role
  @role
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1834
1835
1836
1837
# File 'lib/google/apis/file_v1/classes.rb', line 1834

def update!(**args)
  @replicas = args[:replicas] if args.key?(:replicas)
  @role = args[:role] if args.key?(:role)
end