Class: Google::Apis::FileV1::Instance
- Inherits:
-
Object
- Object
- Google::Apis::FileV1::Instance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1/classes.rb,
lib/google/apis/file_v1/representations.rb,
lib/google/apis/file_v1/representations.rb
Overview
A Filestore instance.
Instance Attribute Summary collapse
-
#capacity_step_size_gb ⇒ Fixnum
Output only.
-
#create_time ⇒ String
Output only.
-
#custom_performance_supported ⇒ Boolean
(also: #custom_performance_supported?)
Output only.
-
#deletion_protection_enabled ⇒ Boolean
(also: #deletion_protection_enabled?)
Optional.
-
#deletion_protection_reason ⇒ String
Optional.
-
#description ⇒ String
The description of the instance (2048 characters or less).
-
#directory_services ⇒ Google::Apis::FileV1::DirectoryServicesConfig
Directory Services configuration for Kerberos-based authentication.
-
#etag ⇒ String
Server-specified ETag for the instance resource to prevent simultaneous updates from overwriting each other.
-
#file_shares ⇒ Array<Google::Apis::FileV1::FileShareConfig>
File system shares on the instance.
-
#kms_key_name ⇒ String
KMS key name used for data encryption.
-
#labels ⇒ Hash<String,String>
Resource labels to represent user provided metadata.
-
#max_capacity_gb ⇒ Fixnum
Output only.
-
#min_capacity_gb ⇒ Fixnum
Output only.
-
#name ⇒ String
Output only.
-
#networks ⇒ Array<Google::Apis::FileV1::NetworkConfig>
VPC networks to which the instance is connected.
-
#performance_config ⇒ Google::Apis::FileV1::PerformanceConfig
Used for setting the performance configuration.
-
#performance_limits ⇒ Google::Apis::FileV1::PerformanceLimits
The enforced performance limits, calculated from the instance's performance configuration.
-
#protocol ⇒ String
Immutable.
-
#replication ⇒ Google::Apis::FileV1::Replication
Optional.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#status_message ⇒ String
Output only.
-
#suspension_reasons ⇒ Array<String>
Output only.
-
#tags ⇒ Hash<String,String>
Optional.
-
#tier ⇒ String
The service tier of the instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Instance
constructor
A new instance of Instance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Instance
Returns a new instance of Instance.
1011 1012 1013 |
# File 'lib/google/apis/file_v1/classes.rb', line 1011 def initialize(**args) update!(**args) end |
Instance Attribute Details
#capacity_step_size_gb ⇒ Fixnum
Output only. The incremental increase or decrease in capacity, designated in
some number of GB.
Corresponds to the JSON property capacityStepSizeGb
859 860 861 |
# File 'lib/google/apis/file_v1/classes.rb', line 859 def capacity_step_size_gb @capacity_step_size_gb end |
#create_time ⇒ String
Output only. The time when the instance was created.
Corresponds to the JSON property createTime
864 865 866 |
# File 'lib/google/apis/file_v1/classes.rb', line 864 def create_time @create_time end |
#custom_performance_supported ⇒ Boolean Also known as: custom_performance_supported?
Output only. Indicates whether this instance supports configuring its
performance. If true, the user can configure the instance's performance by
using the 'performance_config' field.
Corresponds to the JSON property customPerformanceSupported
871 872 873 |
# File 'lib/google/apis/file_v1/classes.rb', line 871 def custom_performance_supported @custom_performance_supported end |
#deletion_protection_enabled ⇒ Boolean Also known as: deletion_protection_enabled?
Optional. Indicates whether the instance is protected against deletion.
Corresponds to the JSON property deletionProtectionEnabled
877 878 879 |
# File 'lib/google/apis/file_v1/classes.rb', line 877 def deletion_protection_enabled @deletion_protection_enabled end |
#deletion_protection_reason ⇒ String
Optional. The reason for enabling deletion protection.
Corresponds to the JSON property deletionProtectionReason
883 884 885 |
# File 'lib/google/apis/file_v1/classes.rb', line 883 def deletion_protection_reason @deletion_protection_reason end |
#description ⇒ String
The description of the instance (2048 characters or less).
Corresponds to the JSON property description
888 889 890 |
# File 'lib/google/apis/file_v1/classes.rb', line 888 def description @description end |
#directory_services ⇒ Google::Apis::FileV1::DirectoryServicesConfig
Directory Services configuration for Kerberos-based authentication.
Corresponds to the JSON property directoryServices
893 894 895 |
# File 'lib/google/apis/file_v1/classes.rb', line 893 def directory_services @directory_services end |
#etag ⇒ String
Server-specified ETag for the instance resource to prevent simultaneous
updates from overwriting each other.
Corresponds to the JSON property etag
899 900 901 |
# File 'lib/google/apis/file_v1/classes.rb', line 899 def etag @etag end |
#file_shares ⇒ Array<Google::Apis::FileV1::FileShareConfig>
File system shares on the instance. For this version, only a single file share
is supported.
Corresponds to the JSON property fileShares
905 906 907 |
# File 'lib/google/apis/file_v1/classes.rb', line 905 def file_shares @file_shares end |
#kms_key_name ⇒ String
KMS key name used for data encryption.
Corresponds to the JSON property kmsKeyName
910 911 912 |
# File 'lib/google/apis/file_v1/classes.rb', line 910 def kms_key_name @kms_key_name end |
#labels ⇒ Hash<String,String>
Resource labels to represent user provided metadata.
Corresponds to the JSON property labels
915 916 917 |
# File 'lib/google/apis/file_v1/classes.rb', line 915 def labels @labels end |
#max_capacity_gb ⇒ Fixnum
Output only. The maximum capacity of the instance in GB.
Corresponds to the JSON property maxCapacityGb
920 921 922 |
# File 'lib/google/apis/file_v1/classes.rb', line 920 def max_capacity_gb @max_capacity_gb end |
#min_capacity_gb ⇒ Fixnum
Output only. The minimum capacity of the instance in GB.
Corresponds to the JSON property minCapacityGb
925 926 927 |
# File 'lib/google/apis/file_v1/classes.rb', line 925 def min_capacity_gb @min_capacity_gb end |
#name ⇒ String
Output only. The resource name of the instance, in the format projects/
project/locations/location/instances/instance`.
Corresponds to the JSON propertyname`
931 932 933 |
# File 'lib/google/apis/file_v1/classes.rb', line 931 def name @name end |
#networks ⇒ Array<Google::Apis::FileV1::NetworkConfig>
VPC networks to which the instance is connected. For this version, only a
single network is supported.
Corresponds to the JSON property networks
937 938 939 |
# File 'lib/google/apis/file_v1/classes.rb', line 937 def networks @networks end |
#performance_config ⇒ Google::Apis::FileV1::PerformanceConfig
Used for setting the performance configuration. If the user doesn't specify
PerformanceConfig, automatically provision the default performance settings as
described in https://cloud.google.com/filestore/docs/performance. Larger
instances will be linearly set to more IOPS. If the instance's capacity is
increased or decreased, its performance will be automatically adjusted upwards
or downwards accordingly (respectively).
Corresponds to the JSON property performanceConfig
947 948 949 |
# File 'lib/google/apis/file_v1/classes.rb', line 947 def performance_config @performance_config end |
#performance_limits ⇒ Google::Apis::FileV1::PerformanceLimits
The enforced performance limits, calculated from the instance's performance
configuration.
Corresponds to the JSON property performanceLimits
953 954 955 |
# File 'lib/google/apis/file_v1/classes.rb', line 953 def performance_limits @performance_limits end |
#protocol ⇒ String
Immutable. The protocol indicates the access protocol for all shares in the
instance. This field is immutable and it cannot be changed after the instance
has been created. Default value: NFS_V3.
Corresponds to the JSON property protocol
960 961 962 |
# File 'lib/google/apis/file_v1/classes.rb', line 960 def protocol @protocol end |
#replication ⇒ Google::Apis::FileV1::Replication
Optional. The configuration used to replicate an instance.
Corresponds to the JSON property replication
965 966 967 |
# File 'lib/google/apis/file_v1/classes.rb', line 965 def replication @replication end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
970 971 972 |
# File 'lib/google/apis/file_v1/classes.rb', line 970 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
976 977 978 |
# File 'lib/google/apis/file_v1/classes.rb', line 976 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The instance state.
Corresponds to the JSON property state
982 983 984 |
# File 'lib/google/apis/file_v1/classes.rb', line 982 def state @state end |
#status_message ⇒ String
Output only. Additional information about the instance state, if available.
Corresponds to the JSON property statusMessage
987 988 989 |
# File 'lib/google/apis/file_v1/classes.rb', line 987 def @status_message end |
#suspension_reasons ⇒ Array<String>
Output only. Field indicates all the reasons the instance is in "SUSPENDED"
state.
Corresponds to the JSON property suspensionReasons
993 994 995 |
# File 'lib/google/apis/file_v1/classes.rb', line 993 def suspension_reasons @suspension_reasons end |
#tags ⇒ Hash<String,String>
Optional. Input only. Immutable. Tag key-value pairs bound to this resource.
Each key must be a namespaced name and each value a short name. Example: "
123456789012/environment" : "production", "123456789013/costCenter" : "
marketing" See the documentation for more information: - Namespaced name:
https://cloud.google.com/resource-manager/docs/tags/tags-creating-and-managing#
retrieving_tag_key - Short name: https://cloud.google.com/resource-manager/
docs/tags/tags-creating-and-managing#retrieving_tag_value
Corresponds to the JSON property tags
1004 1005 1006 |
# File 'lib/google/apis/file_v1/classes.rb', line 1004 def @tags end |
#tier ⇒ String
The service tier of the instance.
Corresponds to the JSON property tier
1009 1010 1011 |
# File 'lib/google/apis/file_v1/classes.rb', line 1009 def tier @tier end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/google/apis/file_v1/classes.rb', line 1016 def update!(**args) @capacity_step_size_gb = args[:capacity_step_size_gb] if args.key?(:capacity_step_size_gb) @create_time = args[:create_time] if args.key?(:create_time) @custom_performance_supported = args[:custom_performance_supported] if args.key?(:custom_performance_supported) @deletion_protection_enabled = args[:deletion_protection_enabled] if args.key?(:deletion_protection_enabled) @deletion_protection_reason = args[:deletion_protection_reason] if args.key?(:deletion_protection_reason) @description = args[:description] if args.key?(:description) @directory_services = args[:directory_services] if args.key?(:directory_services) @etag = args[:etag] if args.key?(:etag) @file_shares = args[:file_shares] if args.key?(:file_shares) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @labels = args[:labels] if args.key?(:labels) @max_capacity_gb = args[:max_capacity_gb] if args.key?(:max_capacity_gb) @min_capacity_gb = args[:min_capacity_gb] if args.key?(:min_capacity_gb) @name = args[:name] if args.key?(:name) @networks = args[:networks] if args.key?(:networks) @performance_config = args[:performance_config] if args.key?(:performance_config) @performance_limits = args[:performance_limits] if args.key?(:performance_limits) @protocol = args[:protocol] if args.key?(:protocol) @replication = args[:replication] if args.key?(:replication) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @status_message = args[:status_message] if args.key?(:status_message) @suspension_reasons = args[:suspension_reasons] if args.key?(:suspension_reasons) @tags = args[:tags] if args.key?(:tags) @tier = args[:tier] if args.key?(:tier) end |