Class: Google::Apis::FileV1::LdapConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1/classes.rb,
lib/google/apis/file_v1/representations.rb,
lib/google/apis/file_v1/representations.rb

Overview

LdapConfig contains all the parameters for connecting to LDAP servers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LdapConfig

Returns a new instance of LdapConfig.



1078
1079
1080
# File 'lib/google/apis/file_v1/classes.rb', line 1078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainString

Required. The LDAP domain name in the format of my-domain.com. Corresponds to the JSON property domain

Returns:

  • (String)


1053
1054
1055
# File 'lib/google/apis/file_v1/classes.rb', line 1053

def domain
  @domain
end

#groups_ouString

Optional. The groups Organizational Unit (OU) is optional. This parameter is a hint to allow faster lookup in the LDAP namespace. In case that this parameter is not provided, Filestore instance will query the whole LDAP namespace. Corresponds to the JSON property groupsOu

Returns:

  • (String)


1060
1061
1062
# File 'lib/google/apis/file_v1/classes.rb', line 1060

def groups_ou
  @groups_ou
end

#serversArray<String>

Required. The servers names are used for specifying the LDAP servers names. The LDAP servers names can come with two formats: 1. DNS name, for example: ldap.example1.com, ldap.example2.com. 2. IP address, for example: 10.0.0.1 , 10.0.0.2, 10.0.0.3. All servers names must be in the same format: either all DNS names or all IP addresses. Corresponds to the JSON property servers

Returns:

  • (Array<String>)


1069
1070
1071
# File 'lib/google/apis/file_v1/classes.rb', line 1069

def servers
  @servers
end

#users_ouString

Optional. The users Organizational Unit (OU) is optional. This parameter is a hint to allow faster lookup in the LDAP namespace. In case that this parameter is not provided, Filestore instance will query the whole LDAP namespace. Corresponds to the JSON property usersOu

Returns:

  • (String)


1076
1077
1078
# File 'lib/google/apis/file_v1/classes.rb', line 1076

def users_ou
  @users_ou
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1083
1084
1085
1086
1087
1088
# File 'lib/google/apis/file_v1/classes.rb', line 1083

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @groups_ou = args[:groups_ou] if args.key?(:groups_ou)
  @servers = args[:servers] if args.key?(:servers)
  @users_ou = args[:users_ou] if args.key?(:users_ou)
end