Class: Google::Apis::FileV1::ListInstancesResponse
- Inherits:
-
Object
- Object
- Google::Apis::FileV1::ListInstancesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1/classes.rb,
lib/google/apis/file_v1/representations.rb,
lib/google/apis/file_v1/representations.rb
Overview
ListInstancesResponse is the result of ListInstancesRequest.
Instance Attribute Summary collapse
-
#instances ⇒ Array<Google::Apis::FileV1::Instance>
A list of instances in the project for the specified location.
-
#next_page_token ⇒ String
The token you can use to retrieve the next page of results.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListInstancesResponse
constructor
A new instance of ListInstancesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListInstancesResponse
Returns a new instance of ListInstancesResponse.
1150 1151 1152 |
# File 'lib/google/apis/file_v1/classes.rb', line 1150 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Google::Apis::FileV1::Instance>
A list of instances in the project for the specified location. If the
location value in the request is "-", the response contains a list of
instances from all locations. If any location is unreachable, the response
will only return instances in reachable locations and the "unreachable" field
will be populated with a list of unreachable locations.
Corresponds to the JSON property instances
1137 1138 1139 |
# File 'lib/google/apis/file_v1/classes.rb', line 1137 def instances @instances end |
#next_page_token ⇒ String
The token you can use to retrieve the next page of results. Not returned if
there are no more results in the list.
Corresponds to the JSON property nextPageToken
1143 1144 1145 |
# File 'lib/google/apis/file_v1/classes.rb', line 1143 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unordered list. Locations that could not be reached.
Corresponds to the JSON property unreachable
1148 1149 1150 |
# File 'lib/google/apis/file_v1/classes.rb', line 1148 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1155 1156 1157 1158 1159 |
# File 'lib/google/apis/file_v1/classes.rb', line 1155 def update!(**args) @instances = args[:instances] if args.key?(:instances) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |