Class: Google::Apis::FileV1::NetworkConfig
- Inherits:
-
Object
- Object
- Google::Apis::FileV1::NetworkConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1/classes.rb,
lib/google/apis/file_v1/representations.rb,
lib/google/apis/file_v1/representations.rb
Overview
Network configuration for the instance.
Instance Attribute Summary collapse
-
#connect_mode ⇒ String
The network connect mode of the Filestore instance.
-
#ip_addresses ⇒ Array<String>
Output only.
-
#modes ⇒ Array<String>
Internet protocol versions for which the instance has IP addresses assigned.
-
#network ⇒ String
The name of the Google Compute Engine VPC network to which the instance is connected.
-
#psc_config ⇒ Google::Apis::FileV1::PscConfig
Private Service Connect configuration.
-
#reserved_ip_range ⇒ String
Optional, reserved_ip_range can have one of the following two types of values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkConfig
constructor
A new instance of NetworkConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkConfig
Returns a new instance of NetworkConfig.
1440 1441 1442 |
# File 'lib/google/apis/file_v1/classes.rb', line 1440 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connect_mode ⇒ String
The network connect mode of the Filestore instance. If not provided, the
connect mode defaults to DIRECT_PEERING.
Corresponds to the JSON property connectMode
1396 1397 1398 |
# File 'lib/google/apis/file_v1/classes.rb', line 1396 def connect_mode @connect_mode end |
#ip_addresses ⇒ Array<String>
Output only. IPv4 addresses in the format octet1`.`octet2`.`octet3`.`octet4
or IPv6 addresses in the format block1`:`block2`:`block3`:`block4`:`block5`:
`block6`:`block7`:`block8.
Corresponds to the JSON property ipAddresses
1403 1404 1405 |
# File 'lib/google/apis/file_v1/classes.rb', line 1403 def ip_addresses @ip_addresses end |
#modes ⇒ Array<String>
Internet protocol versions for which the instance has IP addresses assigned.
For this version, only MODE_IPV4 is supported.
Corresponds to the JSON property modes
1409 1410 1411 |
# File 'lib/google/apis/file_v1/classes.rb', line 1409 def modes @modes end |
#network ⇒ String
The name of the Google Compute Engine VPC network to which the instance is connected.
Corresponds to the JSON property network
1415 1416 1417 |
# File 'lib/google/apis/file_v1/classes.rb', line 1415 def network @network end |
#psc_config ⇒ Google::Apis::FileV1::PscConfig
Private Service Connect configuration.
Corresponds to the JSON property pscConfig
1420 1421 1422 |
# File 'lib/google/apis/file_v1/classes.rb', line 1420 def psc_config @psc_config end |
#reserved_ip_range ⇒ String
Optional, reserved_ip_range can have one of the following two types of values.
- CIDR range value when using DIRECT_PEERING connect mode. * Allocated IP
address range when using PRIVATE_SERVICE_ACCESS connect mode.
When the name of an allocated IP address range is specified, it must be one of
the ranges associated with the private service access connection. When
specified as a direct CIDR value, it must be a /29 CIDR block for Basic tier,
a /24 CIDR block for High Scale tier, or a /26 CIDR block for Enterprise tier
in one of the internal IP address ranges that identifies the range of IP
addresses reserved for this instance. For example, 10.0.0.0/29, 192.168.0.0/24
or 192.168.0.0/26, respectively. The range you specify can't overlap with
either existing subnets or assigned IP address ranges for other Filestore
instances in the selected VPC network.
Corresponds to the JSON property
reservedIpRange
1438 1439 1440 |
# File 'lib/google/apis/file_v1/classes.rb', line 1438 def reserved_ip_range @reserved_ip_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1445 1446 1447 1448 1449 1450 1451 1452 |
# File 'lib/google/apis/file_v1/classes.rb', line 1445 def update!(**args) @connect_mode = args[:connect_mode] if args.key?(:connect_mode) @ip_addresses = args[:ip_addresses] if args.key?(:ip_addresses) @modes = args[:modes] if args.key?(:modes) @network = args[:network] if args.key?(:network) @psc_config = args[:psc_config] if args.key?(:psc_config) @reserved_ip_range = args[:reserved_ip_range] if args.key?(:reserved_ip_range) end |