Class: Google::Apis::FileV1::PromoteReplicaRequest
- Inherits:
-
Object
- Object
- Google::Apis::FileV1::PromoteReplicaRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1/classes.rb,
lib/google/apis/file_v1/representations.rb,
lib/google/apis/file_v1/representations.rb
Overview
PromoteReplicaRequest promotes a Filestore standby instance (replica).
Instance Attribute Summary collapse
-
#peer_instance ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PromoteReplicaRequest
constructor
A new instance of PromoteReplicaRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PromoteReplicaRequest
Returns a new instance of PromoteReplicaRequest.
1737 1738 1739 |
# File 'lib/google/apis/file_v1/classes.rb', line 1737 def initialize(**args) update!(**args) end |
Instance Attribute Details
#peer_instance ⇒ String
Optional. The resource name of the peer instance to promote, in the format
projects/project_id/locations/location_id/instances/instance_id`. The
peer instance is required if the operation is called on an active instance.
Corresponds to the JSON propertypeerInstance`
1735 1736 1737 |
# File 'lib/google/apis/file_v1/classes.rb', line 1735 def peer_instance @peer_instance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1742 1743 1744 |
# File 'lib/google/apis/file_v1/classes.rb', line 1742 def update!(**args) @peer_instance = args[:peer_instance] if args.key?(:peer_instance) end |