Class: Google::Apis::FileV1::Schedule
- Inherits:
-
Object
- Object
- Google::Apis::FileV1::Schedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1/classes.rb,
lib/google/apis/file_v1/representations.rb,
lib/google/apis/file_v1/representations.rb
Overview
Configure the schedule.
Instance Attribute Summary collapse
-
#day ⇒ String
Allows to define schedule that runs specified day of the week.
-
#duration ⇒ String
Output only.
-
#start_time ⇒ Google::Apis::FileV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schedule
constructor
A new instance of Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schedule
Returns a new instance of Schedule.
1925 1926 1927 |
# File 'lib/google/apis/file_v1/classes.rb', line 1925 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Allows to define schedule that runs specified day of the week.
Corresponds to the JSON property day
1911 1912 1913 |
# File 'lib/google/apis/file_v1/classes.rb', line 1911 def day @day end |
#duration ⇒ String
Output only. Duration of the time window, set by service producer.
Corresponds to the JSON property duration
1916 1917 1918 |
# File 'lib/google/apis/file_v1/classes.rb', line 1916 def duration @duration end |
#start_time ⇒ Google::Apis::FileV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
1923 1924 1925 |
# File 'lib/google/apis/file_v1/classes.rb', line 1923 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1930 1931 1932 1933 1934 |
# File 'lib/google/apis/file_v1/classes.rb', line 1930 def update!(**args) @day = args[:day] if args.key?(:day) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |